<?php

namespace Litecms\Employeeteam\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Employeeteam\Models\EmployeeTeam;

class EmployeeTeamPolicy
{

    /**
     * Determine if the given user can view the employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function view(UserPolicy $user, EmployeeTeam $employee_team)
    {
        if ($user->canDo('employeeteam.employee_team.view') && $user->isAdmin()) {
            return true;
        }

        return $employee_team->user_id == user_id() && $employee_team->user_type == user_type();
    }

    /**
     * Determine if the given user can create a employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('employeeteam.employee_team.create');
    }

    /**
     * Determine if the given user can update the given employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function update(UserPolicy $user, EmployeeTeam $employee_team)
    {
        if ($user->canDo('employeeteam.employee_team.edit') && $user->isAdmin()) {
            return true;
        }

        return $employee_team->user_id == user_id() && $employee_team->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EmployeeTeam $employee_team)
    {
        return $employee_team->user_id == user_id() && $employee_team->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EmployeeTeam $employee_team)
    {
        if ($user->canDo('employeeteam.employee_team.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee_team.
     *
     * @param UserPolicy $user
     * @param EmployeeTeam $employee_team
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EmployeeTeam $employee_team)
    {
        if ($user->canDo('employeeteam.employee_team.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
