<?php

namespace Litecms\Employeeteam\Providers;

use Illuminate\Support\ServiceProvider;

class EmployeeteamServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'employeeteam');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'employeeteam');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.employeeteam', function ($app) {
            return $this->app->make('Litecms\Employeeteam\Employeeteam');
        });

                // Bind EmployeeTeam to repository
        $this->app->bind(
            'Litecms\Employeeteam\Interfaces\EmployeeTeamRepositoryInterface',
            \Litecms\Employeeteam\Repositories\Eloquent\EmployeeTeamRepository::class
        );

        $this->app->register(\Litecms\Employeeteam\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Employeeteam\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Employeeteam\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.employeeteam'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/employeeteam.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/employeeteam')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/employeeteam')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
